@@ -1,18 +1,11 @@
-# region Backwards Compatibility
-from __future__ import (
-    nested_scopes, generators, division, absolute_import, with_statement,
-    print_function, unicode_literals
-)
-
-from sob.utilities.compatibility import backport
-
 import os
 import re
 import collections
 
-from warnings import warn
 from collections import OrderedDict
 from io import IOBase
+from urllib.parse import urlparse, urljoin
+from urllib.request import urlopen
 
 from sob import __name__ as _sob_module_name
 from sob import meta
@@ -21,26 +14,17 @@ from sob.utilities import (
     get_source, property_name, properties_values, class_name,
     calling_function_qualified_name
 )
-from sob.utilities.compatibility import (
-    typing, backport, urlopen, urljoin, urlparse
-)
+from sob.utilities.string import split_long_comment_line
 from sob.model import (
     Model as ModelBase, Object, Dictionary, Array,
     from_meta as model_from_meta
 )
 from sob.utilities import qualified_name, url_relative_to
-from sob.properties import Property, Null
+from sob.properties import Property
+from sob.properties.types import Null
 from .oas.references import Resolver
 from .oas.model import OpenAPI, Schema, Reference, Parameter, Operation
-
-backport()
-
-Iterable = typing.Iterable
-Sequence = typing.Sequence
-Optional = typing.Optional
-Union = typing.Union
-
-# Constants
+from typing import Iterable, Sequence, Optional, Union
 
 _META_MODULE_QUALIFIED_NAME = qualified_name(meta)
 _META_PROPERTIES_QAULIFIED_NAME = qualified_name(meta.Properties)
@@ -55,6 +39,7 @@ _DOC_POINTER_RE = re.compile(
     re.DOTALL
 )
 _SPACES_RE = re.compile(r'[\s\n]')
+_LINE_LENGTH = 79  # type: int
 
 # region Functions
 
@@ -77,8 +62,8 @@ def schema_defines_object(schema):
     `Object`.
     """
     return (
-        schema.type_ == 'object' and
         schema.properties and
+        schema.type_ in ('object', None) and
         (not schema.additional_properties)
     )
 
@@ -121,7 +106,7 @@ def operation_defines_model(operation):
 # region Private Classes
 
 
-class _RecursiveReferencePlaceholder(object):
+class _RecursiveReferencePlaceholder:
 
     def __init__(self, relative_url_pointer):
         # type: (str) -> None
@@ -134,7 +119,7 @@ class _RecursiveReferencePlaceholder(object):
         )
 
 
-class _Modeler(object):
+class _Modeler:
     """
     This class parses an OpenAPI schema and produces a data model based on the
     `sob` library.
@@ -835,14 +820,12 @@ class _Modeler(object):
         relative_url_pointer = self.get_class_name_relative_url_pointer(
             class_name_
         )
-        lines = []
-        if len(relative_url_pointer) > 79:
-            pointer_split = relative_url_pointer.split('#')
-            lines.append('# ' + pointer_split[0])
-            lines.append('# #' + '#'.join(pointer_split[1:]))
-        else:
-            lines.append('# ' + relative_url_pointer)
-
+        lines = list()
+        lines.append(
+            split_long_comment_line(
+                '# ' + relative_url_pointer
+            )
+        )
         for property_name_, value in properties_values(meta_):
             if value is not None:
                 value = repr(value)
@@ -854,11 +837,22 @@ class _Modeler(object):
                         -1
                     ]
                 lines.append(
-                    '%s.writable(%s).%s = %s' % (
+                    '%s.writable(\n    %s%s\n).%s = %s' % (
                         _META_MODULE_QUALIFIED_NAME,
                         class_name_,
+                        (
+                            '  # noqa'
+                            if len(class_name_) + 4 > _LINE_LENGTH else
+                            ''
+                        ),
                         property_name_,
-                        value
+                        '\n'.join(
+                            line + (
+                                '  # noqa'
+                                if len(line) > _LINE_LENGTH else ''
+                            )
+                            for line in value.split('\n')
+                        )
                     )
                 )
         return '\n'.join(lines) + '\n'
@@ -894,7 +888,7 @@ class _Modeler(object):
         return '\n'.join(module_contents)
 
 
-class _ModuleParser(object):
+class _ModuleParser:
 
     def __init__(self, path=None):
         # type: (Optional[str]) -> None
@@ -955,7 +949,7 @@ class _ModuleParser(object):
 # region Public Classes
 
 
-class Module(object):
+class Module:
     """
     This class parses an Open API document and outputs a module defining
     classes to represent each schema defined in the Open API document as a
